@@ -18,6 +18,8 @@ pub type ErrorCode = ffi::gpg_err_code_t;
 #[derive(Copy, Clone, Eq, PartialEq, Hash)]
 pub struct Error(ffi::gpg_error_t);
 
+include!("consts.rs");
+
 impl Error {
     /// Creates a new error from a raw error value.
     #[inline]
@@ -208,13 +210,6 @@ impl fmt::Display for Error {
     }
 }
 
-impl From<NulError> for Error {
-    #[inline]
-    fn from(_: NulError) -> Self {
-        Self::EINVAL
-    }
-}
-
 impl From<Infallible> for Error {
     #[inline]
     fn from(x: Infallible) -> Self {
@@ -222,6 +217,13 @@ impl From<Infallible> for Error {
     }
 }
 
+impl From<NulError> for Error {
+    #[inline]
+    fn from(_: NulError) -> Self {
+        Self::EINVAL
+    }
+}
+
 impl From<TryFromIntError> for Error {
     #[inline]
     fn from(_: TryFromIntError) -> Self {
@@ -279,8 +281,6 @@ impl From<Error> for io::Error {
     }
 }
 
-include!(concat!(env!("OUT_DIR"), "/constants.rs"));
-
 pub type Result<T, E = Error> = result::Result<T, E>;
 
 #[macro_export]
